import React from 'react';
import { render, shallow } from 'enzyme';
import sinon from 'sinon';
import SortableTable from './SortableTable';
describe('<SortableTable>', function () {
  var columns = [{
    header: 'Name',
    key: 'name'
  }, {
    header: 'Age',
    key: 'age'
  }, {
    header: 'Employee-id',
    key: 'id'
  }, {
    header: '',
    key: 'button'
  }];
  var data = [{
    name: 'Zombie Mountain',
    age: 36,
    id: 2,
    button: React.createElement("button", null, "poke")
  }, {
    name: 'Daenerys Targaryen',
    age: 16,
    id: 4,
    button: React.createElement("button", null, "poke")
  }, {
    name: 'Ned Stark',
    age: 48,
    id: 3,
    button: React.createElement("button", null, "poke")
  }, {
    name: 'Jon Snow',
    age: 20,
    id: 1,
    button: React.createElement("button", null, "poke")
  }];
  var wrapper = render(React.createElement(SortableTable, {
    columns: columns,
    data: data
  }));
  it('should show right amount of th tags', function () {
    expect(wrapper.find('th')).toHaveLength(columns.length);
  });
  it('should render a row for each data array entry', function () {
    expect(wrapper.find('tbody tr')).toHaveLength(data.length);
  });
  it('should set data-th property on each cell rendered', function () {
    expect(wrapper.find('[data-th]')).toHaveLength(data.length * columns.length);
  });
  it('should add `aria-sort` property', function () {
    expect(wrapper.find('[aria-sort]')).toHaveLength(columns.length);
  });
  it('should not show sorting arrow if header is blank string', function () {
    expect(wrapper.find('.ffe-sortable-table__sort-arrow').length).toBe(columns.length - 1);
  });
  it('should show buttons in table when passing in buttons in data', function () {
    expect(wrapper.find('button').length).toBe(data.length);
  });
  it('should call onSort after sorting table', function () {
    var onSort = sinon.spy();
    var table = shallow(React.createElement(SortableTable, {
      columns: columns,
      data: data,
      onSort: onSort
    }));
    table.instance().tableHeaderClicked('name');
    sinon.assert.calledWith(onSort, sinon.match(function (val) {
      return 'sortBy' in val && 'descending' in val && 'tableData' in val;
    }));
  });
  describe('condensed', function () {
    it('should by default not be condensed', function () {
      return expect(wrapper.find('.ffe-table--condensed')).toHaveLength(0);
    });
    var condensedWrapper = render(React.createElement(SortableTable, {
      condensed: true,
      columns: columns,
      data: data
    }));
    it('can be condensed', function () {
      return expect(condensedWrapper).toHaveLength(1);
    });
  });
});