import React from 'react';
import { shallow, render } from 'enzyme';
import TableRowExpandable from './TableRowExpandable';
var props = {
  cells: {
    name: 'Ola Normann',
    address: 'Gateveien 2',
    age: 23,
    phone: '912 34 567',
    email: 'ola@normann.no'
  },
  columns: [{
    key: 'name',
    content: 'Navn'
  }, {
    key: 'address',
    content: 'Adresse'
  }, {
    key: 'age',
    content: 'Alder',
    alignRight: true
  }, {
    key: 'phone',
    content: 'Telefon'
  }, {
    key: 'email',
    content: 'E-post'
  }]
};
var wrapper = shallow(React.createElement(TableRowExpandable, props, React.createElement("p", null, "The cake is a lie")));
var unexpandableWrapper = shallow(React.createElement(TableRowExpandable, props, false && React.createElement("div", null, "Ignorance is bliss, and we won't render this")));
describe('<TableRowExpandable>', function () {
  it('should be collapsed by default', function () {
    expect(wrapper.state().expanded).toBe(false);
    expect(wrapper.find('.ffe-table__row-expandable--expanded')).toHaveLength(0);
    expect(wrapper.find('.ffe-table__row-expandable-content').prop('aria-hidden')).toBe('true');
    expect(wrapper.find('.ffe-table__row-expandable-content').hasClass('ffe-table__row--collapsed')).toBe(true);
  });
  it('should render expanded content', function () {
    wrapper.setState({
      expanded: true
    });
    expect(wrapper.find('td').last().find('p').text()).toBe('The cake is a lie');
    expect(wrapper.find('tr').last().hasClass('ffe-table__row-expandable-content--expanded')).toBe(true);
    expect(wrapper.find('tr').last().hasClass('ffe-table__row--collapsed')).toBe(false);
  });
  it('should pass correct props to TableRow component', function () {
    wrapper.setState({
      expanded: true
    });
    var tableRow = wrapper.find('TableRow').props();
    expect(tableRow.expanded).toBe(true);
    expect(tableRow.columns).toBe(props.columns);
    expect(tableRow.trClasses).toContain('ffe-table__row-expandable--expanded');
  });
  it('should pass an expand icon with correct classname to TableRow', function () {
    wrapper.setState({
      expanded: true
    });
    var tableRow = wrapper.find('TableRow').props();
    expect(tableRow.cells.expandIcon.props.className).toContain('ffe-table__expand-icon--expanded');
    expect(tableRow.expandable).toBe(true);
  });
  it('should not pass an expand icon to TableRows that are not expandable', function () {
    var tableRow = unexpandableWrapper.find('TableRow').props();
    expect(tableRow.cells.expandIcon).toBe(' ');
    expect(tableRow.expandable).toBe(false);
  });
  var renderedWrapper = render(React.createElement(TableRowExpandable, props, React.createElement("p", null, "a Festivus for the rest of us")));
  it('should render a tbody with two tr', function () {
    expect(renderedWrapper.children()).toHaveLength(2);
  });
  it('should set the correct aria attributes on tr', function () {
    expect(renderedWrapper.find('tr').first().prop('aria-expanded')).toBe('false');
    expect(renderedWrapper.find('tr').last().prop('aria-hidden')).toBe('true');
  });
});