"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _sinon = _interopRequireDefault(require("sinon"));

var _SortableTable = _interopRequireDefault(require("./SortableTable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('<SortableTable>', function () {
  var columns = [{
    header: 'Name',
    key: 'name'
  }, {
    header: 'Age',
    key: 'age'
  }, {
    header: 'Employee-id',
    key: 'id'
  }, {
    header: '',
    key: 'button'
  }];
  var data = [{
    name: 'Zombie Mountain',
    age: 36,
    id: 2,
    button: _react.default.createElement("button", null, "poke")
  }, {
    name: 'Daenerys Targaryen',
    age: 16,
    id: 4,
    button: _react.default.createElement("button", null, "poke")
  }, {
    name: 'Ned Stark',
    age: 48,
    id: 3,
    button: _react.default.createElement("button", null, "poke")
  }, {
    name: 'Jon Snow',
    age: 20,
    id: 1,
    button: _react.default.createElement("button", null, "poke")
  }];
  var wrapper = (0, _enzyme.render)(_react.default.createElement(_SortableTable.default, {
    columns: columns,
    data: data
  }));
  it('should show right amount of th tags', function () {
    expect(wrapper.find('th')).toHaveLength(columns.length);
  });
  it('should render a row for each data array entry', function () {
    expect(wrapper.find('tbody tr')).toHaveLength(data.length);
  });
  it('should set data-th property on each cell rendered', function () {
    expect(wrapper.find('[data-th]')).toHaveLength(data.length * columns.length);
  });
  it('should add `aria-sort` property', function () {
    expect(wrapper.find('[aria-sort]')).toHaveLength(columns.length);
  });
  it('should not show sorting arrow if header is blank string', function () {
    expect(wrapper.find('.ffe-sortable-table__sort-arrow').length).toBe(columns.length - 1);
  });
  it('should show buttons in table when passing in buttons in data', function () {
    expect(wrapper.find('button').length).toBe(data.length);
  });
  it('should call onSort after sorting table', function () {
    var onSort = _sinon.default.spy();

    var table = (0, _enzyme.shallow)(_react.default.createElement(_SortableTable.default, {
      columns: columns,
      data: data,
      onSort: onSort
    }));
    table.instance().tableHeaderClicked('name');

    _sinon.default.assert.calledWith(onSort, _sinon.default.match(function (val) {
      return 'sortBy' in val && 'descending' in val && 'tableData' in val;
    }));
  });
  describe('condensed', function () {
    it('should by default not be condensed', function () {
      return expect(wrapper.find('.ffe-table--condensed')).toHaveLength(0);
    });
    var condensedWrapper = (0, _enzyme.render)(_react.default.createElement(_SortableTable.default, {
      condensed: true,
      columns: columns,
      data: data
    }));
    it('can be condensed', function () {
      return expect(condensedWrapper).toHaveLength(1);
    });
  });
});