"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = require("prop-types");

var _Table = _interopRequireDefault(require("./Table/Table"));

var _SortableTable = _interopRequireDefault(require("./SortableTable/SortableTable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Table = function Table(props) {
  var sortable = props.sortable,
      rest = _objectWithoutProperties(props, ["sortable"]);

  if (sortable) {
    return _react.default.createElement(_SortableTable.default, rest);
  }

  return _react.default.createElement(_Table.default, rest);
};

Table.propTypes = {
  caption: _propTypes.node,

  /** Make the caption only visible for screen readers */
  srOnlyCaption: _propTypes.bool,

  /** A mapping function that returns a renderable node that will be rendered for each expandable row */
  expandedContentMapper: _propTypes.func,
  sortable: _propTypes.bool,

  /** A string reference to a column key to set an initial sort of the table */
  sortBy: _propTypes.string,

  /** Used in conjunction with sortBy */
  descending: _propTypes.bool,

  /** When paginated, lets you set the number of rows to offset from the beginning */
  offset: _propTypes.number,

  /** Limits the number of rows to show on one page. Decides whether or not to paginate your table */
  limit: _propTypes.number,

  /** Makes your table condensed - for pages that show a lot of data */
  condensed: _propTypes.bool,

  /** Set to true if you want the row headings to be narrower on smalls screens */
  smallHeader: _propTypes.bool,

  /** Removes left cell padding from the first column */
  alignLeft: _propTypes.bool,

  /** Show your table as a regular column based table on small devices */
  columnLayoutMobile: _propTypes.bool,

  /** Decide if your table rows should break into a vertical view on small or no devices */
  breakpoint: (0, _propTypes.oneOf)(['sm', 'none']),

  /**
   * Override rendering of rows with a prop
   * rowRender={(props, rowcontent, trprops, index)=>{return <tr {...trprops}>{rowcontent}</tr>}}
   */
  rowRender: _propTypes.func,

  /**
   * Override rendering of headers with a prop
   * headerRender={(props, rowcontent, trprops) => {return <tr {...trprops}>{rowcontent}</tr>}}
   */
  headerRender: _propTypes.func,

  /**
   * Override rendering of footer with a prop
   * footerRender={(props, rowcontent, trprops) => {return <tr {...trprops}>{rowcontent}</tr>}}
   */
  footerRender: _propTypes.func,

  /**
   * An array of objects with keys equal to the columns array's key value, and value equal to whatever you
   * want in your cell. These are basically an array of rows
   **/
  data: (0, _propTypes.arrayOf)((0, _propTypes.shape)({
    /** A unique ID for each row of data. Required for sorting */
    id: (0, _propTypes.oneOfType)([_propTypes.string, _propTypes.number])
  })),

  /** An array of objects with a key describing your column, and a header describing that column */
  columns: (0, _propTypes.arrayOf)((0, _propTypes.shape)({
    /** The column header. Required, but may be an empty string. */
    header: _propTypes.node.isRequired,

    /** The column key used in the `data` array's objects */
    key: _propTypes.string.isRequired,

    /** Content shown in the table footer */
    footer: _propTypes.node,
    alignRight: _propTypes.bool,
    alignTop: _propTypes.bool,
    hideOnDesktop: _propTypes.bool,
    hideOnTablet: _propTypes.bool,
    hideOnSmallTablet: _propTypes.bool,
    hideOnMobile: _propTypes.bool,

    /** Custom comparator function for sorting this column */
    compare: _propTypes.func,

    /** Disable column from sorting. Not needed if heading is an empty string */
    notSortable: _propTypes.bool,
    cellRender: _propTypes.func,
    columnHeaderRender: _propTypes.func,
    columnFooterRender: _propTypes.func
  }).isRequired),

  /** Class names set in addition to the ffe tables classes. */
  className: _propTypes.string
};
var _default = Table;
exports.default = _default;