"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _Table = _interopRequireDefault(require("./Table"));

var _TableRowExpandable = _interopRequireDefault(require("../TableParts/TableRowExpandable"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

describe('<Table />', function () {
  var columns = [{
    key: 'name',
    header: 'Navn'
  }, {
    key: 'address',
    header: 'Adresse'
  }, {
    key: 'age',
    header: 'Alder',
    alignRight: true
  }];
  var columnsWithFooterContent = [{
    key: 'name',
    header: 'Navn',
    footer: 'Sum alder'
  }, {
    key: 'address',
    header: 'Adresse'
  }, {
    key: 'age',
    header: 'Alder',
    footer: 135,
    alignRight: true
  }];
  var data = [{
    name: 'Ola Normann',
    address: 'Gateveien 2',
    age: 23,
    phone: '912 34 567'
  }, {
    name: 'Sivert Svenska',
    address: 'Gatuveio 7',
    age: 45,
    phone: '+46 123 456 789'
  }, {
    name: 'Daniel Dansk',
    address: 'Kartoffel Fjers',
    age: 67,
    phone: '+45 018 456 789'
  }];
  var wrapperWithoutOverride = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
    columns: columnsWithFooterContent,
    data: data
  }));
  describe('general', function () {
    it('renders without exploding', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper).toHaveLength(1);
    });
    it('renders the correct dom structure', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.is('table')).toBe(true);
      expect(wrapper.hasClass('ffe-table')).toBe(true);
      expect(wrapper.hasClass('ffe-table--condensed')).toBe(false);
    });
    it('can be condensed', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        condensed: true,
        columns: columns,
        data: data
      }));
      expect(wrapper.hasClass('ffe-table')).toBe(true);
      expect(wrapper.hasClass('ffe-table--condensed')).toBe(true);
    });
    it('can be left aligned', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        alignLeft: true,
        columns: columns,
        data: data
      }));
      expect(wrapper.hasClass('ffe-table')).toBe(true);
      expect(wrapper.hasClass('ffe-table--text-left')).toBe(true);
    });
    it('can have a two column layout on mobile', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columnLayoutMobile: true,
        columns: columns,
        data: data
      }));
      expect(wrapper.hasClass('ffe-table')).toBe(true);
      expect(wrapper.hasClass('ffe-table--columns-sm')).toBe(true);
    });
    it('applies supplied classes', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data,
        className: "test-class-one test-class-two"
      }));
      expect(wrapper.hasClass('ffe-table')).toBe(true);
      expect(wrapper.hasClass('test-class-one')).toBe(true);
      expect(wrapper.hasClass('test-class-two')).toBe(true);
    });
  });
  describe('table caption', function () {
    it('does not render a <caption /> if caption prop is not provided', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('caption')).toHaveLength(0);
    });
    it('renders a <caption /> if caption prop is provided', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data,
        caption: "A nice table"
      }));
      expect(wrapper.find('caption')).toHaveLength(1);
      expect(wrapper.find('caption').text()).toBe('A nice table');
    });
  });
  describe('table headers', function () {
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
      columns: columns,
      data: data
    }));
    it('renders columns inside a <thead />', function () {
      expect(wrapper.find('thead')).toHaveLength(1);
    });
    it('renders columns as <th /> tags', function () {
      expect(wrapper.find('th')).toHaveLength(3);
    });
    it('renders header content as <th /> content', function () {
      expect(wrapper.find('th').first().text()).toBe(columns[0].header);
    });
  });
  describe('table footer', function () {
    var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
      columns: columnsWithFooterContent,
      data: data
    }));
    it('renders a <tfoot />', function () {
      expect(wrapper.find('tfoot')).toHaveLength(1);
    });
    it('renders the footer content inside <tfoot />', function () {
      expect(wrapper.find('tfoot').find('td').first().text()).toBe('Sum alder');
    });
    it('does not render <tfoot /> unless footer is present in columns', function () {
      var wrapperWithoutFooterContent = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapperWithoutFooterContent.find('tfoot')).toHaveLength(0);
    });
  });
  describe('table footer override', function () {
    var wrapper;
    var mockCallback;
    var columnsForFooterRender = [{
      key: 'name',
      header: 'Navn',
      footer: 'Sum alder'
    }, {
      key: 'address',
      header: 'Adresse',
      columnFooterRender: function columnFooterRender(value, dataWindow, tdProps, spanProps, headerColumns, index) {
        return _react.default.createElement("td", tdProps, _react.default.createElement("span", spanProps, value));
      }
    }, {
      key: 'age',
      header: 'Alder',
      footer: 135,
      alignRight: true
    }];
    var wrapperWithDefaultOverride = wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
      columns: columnsForFooterRender,
      data: data,
      footerRender: function footerRender(trProps, columnsFooter) {
        return _react.default.createElement("tr", trProps);
      }
    }));
    beforeEach(function () {
      mockCallback = jest.fn();
    });
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
        columns: columnsForFooterRender,
        data: data,
        footerRender: function footerRender(trProps, columnsFooter) {
          return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("tr", _extends({}, trProps, {
            a: "customfooter",
            firstkey: columnsFooter[0].key,
            onClick: function onClick(event) {
              mockCallback();
            }
          })), _react.default.createElement("tr", _extends({}, trProps, {
            a: "customfooter",
            firstkey: columnsFooter[0].key,
            onClick: function onClick(event) {
              mockCallback();
            }
          }), trProps.children[0], trProps.children[1], trProps.children[2]));
        }
      }));
    });
    it('renders a <tfoot /> tr has custom props', function () {
      var propKeyProp = wrapper.find('tfoot').find('tr').first().props();
      expect(propKeyProp.a).toBe('customfooter');
      expect(propKeyProp.firstkey).toBe('name');
      expect(wrapper.find('tfoot').find('tr').first().render().attr('a')).toBe('customfooter');
    });
    it('renders a <tfoot />, triggers tr onClick method', function () {
      wrapper.find('tfoot').find('tr').first().simulate('click');
      expect(mockCallback.mock.calls.length).toBe(1);
    });
    it('renders a <tfoot /> that has two identical rows, the second row has array notation', function () {
      var tr0html = wrapper.find('tfoot').find('tr').at(0).html();
      var tr1html = wrapper.find('tfoot').find('tr').at(1).html();
      expect(tr1html).toBe(tr0html);
    });
    it('renders a <tfoot /> with override that should look like the default', function () {
      var withoutOverrideHtml = wrapperWithoutOverride.find('tfoot').first().html();
      var withDefaultOverrideHtml = wrapperWithDefaultOverride.find('tfoot').first().html();
      expect(withDefaultOverrideHtml).toBe(withoutOverrideHtml);
    });
  });
  describe('table header override', function () {
    var wrapper;
    var mockCallback;
    var columnsForFooterRender = [{
      key: 'name',
      header: 'Navn',
      footer: 'Navn'
    }, {
      key: 'address',
      header: 'Adresse'
    }, {
      key: 'age',
      header: 'Alder',
      footer: 135,
      alignRight: true
    }];
    var wrapperWithDefaultOverride = wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
      columns: columnsForFooterRender,
      data: data,
      headerRender: function headerRender(trProps, headerColumns) {
        return _react.default.createElement("tr", trProps);
      }
    }));
    beforeEach(function () {
      mockCallback = jest.fn();
    });
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
        columns: columnsForFooterRender,
        data: data,
        headerRender: function headerRender(trProps, headerColumns) {
          return _react.default.createElement(_react.default.Fragment, null, _react.default.createElement("tr", _extends({}, trProps, {
            a: "customfooter",
            firstkey: headerColumns[0].key,
            onClick: function onClick(event) {
              mockCallback();
            }
          })), _react.default.createElement("tr", _extends({}, trProps, {
            a: "customfooter",
            firstkey: headerColumns[0].key,
            onClick: function onClick(event) {
              mockCallback();
            }
          }), trProps.children[0], trProps.children[1], trProps.children[2]));
        }
      }));
    });
    it('renders a <thead /> tr has custom props', function () {
      var propKeyProp = wrapper.find('thead').find('tr').first().props();
      expect(propKeyProp.a).toBe('customfooter');
      expect(propKeyProp.firstkey).toBe('name');
      expect(wrapper.find('thead').find('tr').first().render().attr('a')).toBe('customfooter');
    });
    it('renders a <thead />, triggers tr onClick method', function () {
      wrapper.find('thead').find('tr').first().simulate('click');
      expect(mockCallback.mock.calls.length).toBe(1);
    });
    it('renders a <thead /> that has two identical rows, the second row has array notation', function () {
      var tr0html = wrapper.find('thead').find('tr').at(0).html();
      var tr1html = wrapper.find('thead').find('tr').at(1).html();
      expect(tr1html).toBe(tr0html);
    });
    it('renders a <thead /> with override that should look like the default', function () {
      var withoutOverrideHtml = wrapperWithoutOverride.find('thead').first().html();
      var withDefaultOverrideHtml = wrapperWithDefaultOverride.find('thead').first().html();
      expect(withDefaultOverrideHtml).toBe(withoutOverrideHtml);
    });
  });
  describe('expandable table rows', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
      columns: [{
        key: 'name',
        header: 'Navn'
      }, {
        key: 'address',
        header: 'Adresse'
      }],
      data: [{
        name: 'First',
        address: 'Expand me'
      }, {
        name: 'Second'
      }],
      expandedContentMapper: function expandedContentMapper(row) {
        return row.address && _react.default.createElement("span", {
          className: "expandedcontent"
        }, "Adresse: ", row.address);
      }
    }));
    it('should render expandable rows when if expandable content is available', function () {
      expect(wrapper.find('tbody').length).toBe(2);
      expect(wrapper.find(_TableRowExpandable.default).length).toBe(1);
    });
  });
  describe('table row render override', function () {
    var wrapper;
    var mockCallback;
    var columnsForRenderOverride = [{
      key: 'name',
      header: 'Navn',
      footer: 'Navn',
      cellRender: function cellRender(value, col, props) {
        return _react.default.createElement(_react.default.Fragment, null, value);
      }
    }, {
      key: 'address',
      header: 'Adresse'
    }, {
      key: 'age',
      header: 'Alder',
      footer: 135,
      alignRight: true
    }];

    var expandedContentMapper = function expandedContentMapper(row) {
      return row.address && _react.default.createElement("span", {
        className: "expandedcontent"
      }, "Adresse: ", row.address);
    };

    var wrapperWithDefaultOverride = wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
      columns: columnsForRenderOverride,
      data: data,
      rowRender: function rowRender(trprops, props, rowIndex) {
        return _react.default.createElement("tr", trprops);
      }
    }));
    var wrapperWithExendedRowAndRenderOverride = wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
      columns: columnsForRenderOverride,
      data: data,
      expandedContentMapper: expandedContentMapper,
      rowRender: function rowRender(trprops, props, rowIndex) {
        return _react.default.createElement("tr", _extends({}, trprops, {
          onClick: function onClick(event) {
            mockCallback();
            trprops.onClick(event);
          }
        }));
      }
    }));
    beforeEach(function () {
      mockCallback = jest.fn();
    });
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_Table.default, {
        columns: columnsForRenderOverride,
        data: data,
        rowRender: function rowRender(trprops, props, rowIndex) {
          return _react.default.createElement("tr", _extends({}, trprops, {
            a: "customfooter",
            onClick: function onClick(event) {
              mockCallback();
            }
          }));
        }
      }));
    });
    it('renders a <tbody /> tr has custom props', function () {
      var propKeyProp = wrapper.find('tbody').find('tr').first().props();
      expect(propKeyProp.a).toBe('customfooter');
      expect(wrapper.find('tbody').find('tr').first().render().attr('a')).toBe('customfooter');
    });
    it('renders a <tbody />, triggers tr onClick method', function () {
      wrapper.find('tbody').find('tr').first().simulate('click');
      expect(mockCallback.mock.calls.length).toBe(1);
    });
    it('renders a <tbody /> with extendedRow, triggers tr onClick method', function () {
      wrapperWithExendedRowAndRenderOverride.find('tbody').first().find('tr').first().simulate('click');
      expect(wrapperWithExendedRowAndRenderOverride.find('tbody').first().find('.ffe-table__row-expandable-content--expanded').length).toBe(1);
      expect(mockCallback.mock.calls.length).toBe(1);
      wrapperWithExendedRowAndRenderOverride.find('tbody').first().find('tr').first().simulate('click');
      expect(wrapperWithExendedRowAndRenderOverride.find('tbody').first().find('.ffe-table__row-expandable-content--expanded').length).toBe(0);
    });
    it('renders a <tbody /> with override that should look like the default', function () {
      var withoutOverrideHtml = wrapperWithoutOverride.find('tbody').first().html();
      var withDefaultOverrideHtml = wrapperWithDefaultOverride.find('tbody').first().html();
      expect(withDefaultOverrideHtml).toBe(withoutOverrideHtml);
    });
  });
  describe('table body', function () {
    it('does not render a tbody if data prop is empty', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: []
      }));
      expect(wrapper.find('tbody')).toHaveLength(0);
    });
    it('renders a tbody if data is provided', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('tbody')).toHaveLength(1);
    });
    it('renders a <tr /> row for each entry in the data prop', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('tbody tr')).toHaveLength(data.length);
    });
    it('renders a <td /> cell for each entry in each row', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('td')).toHaveLength(data.length * columns.length);
    });
    it('renders a content-div inside each td', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('td .ffe-table__content').length).toBe(data.length * columns.length);
    });
    it('renders content of each cell', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: data
      }));
      expect(wrapper.find('td .ffe-table__content').first().text()).toBe(data[0].name);
    });
    it('adds column heading to data-th property of each cell', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        data: data,
        columns: columns
      }));
      expect(wrapper.find('[data-th="Navn"]')).toHaveLength(columns.length);
      expect(wrapper.find('td').first().prop('data-th')).toBe(columns[0].header);
    });
    it('render screen reader only caption', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        data: data,
        columns: columns,
        caption: "Read me",
        srOnlyCaption: true
      }));
      expect(wrapper.find('caption')).toHaveLength(1);
      expect(wrapper.find('caption').hasClass('ffe-screenreader-only')).toBe(true);
      expect(wrapper.find('caption').text()).toBe('Read me');
    });
    it('do not render caption when srOnlyCaption is true but missing caption text', function () {
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        data: data,
        columns: columns,
        srOnlyCaption: true
      }));
      expect(wrapper.find('caption')).toHaveLength(0);
    });
    it('sets correct class for top-alignment on table cells', function () {
      var columnsWithTopAlignment = columns.map(function (column) {
        return _objectSpread({}, column, {
          alignTop: true
        });
      });
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        data: data,
        columns: columnsWithTopAlignment
      }));
      expect(wrapper.find('.ffe-table__cell--top').length).toBe(9);
    });
    it('sets correct class for hiding column on desktop', function () {
      var columnsWithTopAlignment = columns.map(function (column, index) {
        return index === 0 ? _objectSpread({}, column, {
          hideOnDesktop: true
        }) : column;
      });
      var wrapper = (0, _enzyme.render)(_react.default.createElement(_Table.default, {
        data: data,
        columns: columnsWithTopAlignment
      }));
      expect(wrapper.find('.ffe-table--hide-xlg').length).toBe(4);
    });
  });
  describe('offset and limit properties', function () {
    var muchData = 'ABCDEFGHIJKLMNO'.split('').map(function (c, i) {
      return {
        name: c,
        address: "Sesame Street ".concat(i),
        age: i
      };
    });

    var getContentOfFirstColumn = function getContentOfFirstColumn(comp) {
      return comp.find('.ffe-table__cell:first-of-type .ffe-table__content');
    };

    describe('setting limit', function () {
      var contentOfFirstColumn = getContentOfFirstColumn((0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: muchData,
        limit: 3
      })));
      it('reduces number of table rows', function () {
        return expect(contentOfFirstColumn).toHaveLength(3);
      });
      it('does not skip data', function () {
        return expect(contentOfFirstColumn.first().text()).toBe('A');
      });
      it('limits data', function () {
        return expect(contentOfFirstColumn.last().text()).toBe('C');
      });
    });
    describe('setting offset', function () {
      var contentOfFirstColumn = getContentOfFirstColumn((0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: muchData,
        offset: 10
      })));
      it('reduces number of table rows', function () {
        return expect(contentOfFirstColumn).toHaveLength(5);
      });
      it('skips data', function () {
        return expect(contentOfFirstColumn.first().text()).toBe('K');
      });
      it('does not limits data', function () {
        return expect(contentOfFirstColumn.last().text()).toBe('O');
      });
    });
    describe('setting both', function () {
      var contentOfFirstColumn = getContentOfFirstColumn((0, _enzyme.render)(_react.default.createElement(_Table.default, {
        columns: columns,
        data: muchData,
        offset: 5,
        limit: 4
      })));
      it('reduces number of table rows', function () {
        return expect(contentOfFirstColumn).toHaveLength(4);
      });
      it('skips data', function () {
        return expect(contentOfFirstColumn.first().text()).toBe('F');
      });
      it('limits data', function () {
        return expect(contentOfFirstColumn.last().text()).toBe('I');
      });
    });
  });
});