"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _TableCell = _interopRequireDefault(require("./TableCell"));

var _classnames = _interopRequireDefault(require("classnames"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TableFooter = function TableFooter(_ref) {
  var columns = _ref.columns,
      footerRender = _ref.footerRender,
      dataWindow = _ref.dataWindow;
  var footerContent = columns.map(function (column, index) {
    if (column === null) {
      return _react.default.createElement("td", {
        key: index
      });
    }

    var className = (0, _classnames.default)({
      'ffe-table--hide-sm': column.hideOnMobile
    }, {
      'ffe-table--hide-md': column.hideOnSmallTablet
    }, {
      'ffe-table--hide-lg': column.hideOnTablet
    }, {
      'ffe-table--hide-xlg': column.hideOnDesktop
    });
    var dataTh = '';
    var columnHeader = column.header;

    if (columnHeader) {
      if (typeof columnHeader === 'string') {
        dataTh = columnHeader;
      } else if (columnHeader.props && columnHeader.props.children) {
        dataTh = _react.default.Children.toArray(columnHeader.props.children)[0];
      }
    }

    var tdProps = {
      className: (0, _classnames.default)('ffe-table__cell', {
        'ffe-table__cell--top': column.alignTop
      }, className),
      'data-th': dataTh,
      key: index
    };
    var spanProps = {
      className: (0, _classnames.default)('ffe-table__content', {
        'ffe-table__content--text-right': column.alignRight
      })
    };

    if (typeof column.columnFooterRender === "function") {
      return column.columnFooterRender(column.footer, dataWindow, tdProps, spanProps, columns, index);
    }

    return _react.default.createElement(_TableCell.default, {
      key: index,
      columnHeader: column.header,
      alignRight: column.alignRight,
      alignTop: column.alignTop,
      tdClasses: className
    }, column.footer);
  });
  var trProps = {
    className: "ffe-table__row",
    children: footerContent
  };

  var trDefault = _react.default.createElement("tr", trProps);

  var footerRendered = typeof footerRender === "function" ? footerRender(trProps, columns) : trDefault;
  return _react.default.createElement("tfoot", {
    className: "ffe-table__footer"
  }, footerRendered);
};

TableFooter.propTypes = {
  columns: _propTypes.default.arrayOf(_propTypes.default.shape({
    alignRight: _propTypes.default.bool,
    alignTop: _propTypes.default.bool,
    footer: _propTypes.default.any,
    header: _propTypes.default.node.isRequired,
    hideOnDesktop: _propTypes.default.bool,
    hideOnMobile: _propTypes.default.bool,
    hideOnSmallTablet: _propTypes.default.bool,
    hideOnTablet: _propTypes.default.bool
  })),
  footerRender: _propTypes.default.func,
  dataWindow: _propTypes.default.array
};
var _default = TableFooter;
exports.default = _default;